import requests, json



def install_library (lib_name:str, version:str, download_location_path:str):
    URL = f"https://pypi.org/pypi/{lib_name}/json"
    content = requests.get(URL).text
    content = json.loads(content)

    releases = content['releases']

    download_url = releases[f'{version}'][0]['url']

    download_response = requests.get(download_url, stream=True)
    download_response.raise_for_status()

    with open(f"{download_location_path}/{lib_name}.tar.gz", 'wb') as file:
        for chunk in download_response.iter_content():
            file.write(chunk)

if __name__ == "__main__":
    install_library("requests", "2.31.0", "./")


import requests, json



def is_library_exist (library_name:str):
    URL = f"https://pypi.org/pypi/{library_name}/json"
    content = requests.get(URL).text
    content = json.loads(content)

    if 'message' in content:
        if content['message'] == "Not Found":
            return False
    
    return True


import requests, json



def get_all_releases_of_library (library_name:str):
    URL = f"https://pypi.org/pypi/{library_name}/json"
    content = requests.get(URL).text
    content = json.loads(content)

    releases = content['releases']

    rel = []
    for i in releases:
        rel.append(i)

    return rel


if __name__ == "__main__":
    print(get_all_releases_of_library("requests"))


import tarfile, shutil
import os

def uncompress_library (tar_gz_file:str, dst_path:str):
    file_path = tar_gz_file
    
    try:
        tar = tarfile.open(file_path)
        tar.extractall(path=dst_path)
        tar.close()
    except:
        main_path_name = os.path.dirname(tar_gz_file)
        base_name = os.path.basename(tar_gz_file)
        base_name = str(base_name).replace(".tar.gz", ".zip")
        shutil.copy2(tar_gz_file, os.path.join(main_path_name, base_name))
        import zipfile
        with zipfile.ZipFile(os.path.join(main_path_name, base_name), 'r') as zip_ref:
            zip_ref.extractall(dst_path)
        
        os.remove(os.path.join(main_path_name, base_name))

    os.remove(tar_gz_file)

if __name__ == "__main__":
    uncompress_library(tar_gz_file="requests.tar.gz", dst_path="requests")





from .tools.uncompress_library import uncompress_library
from .tools.check_library_exist import is_library_exist
from .tools.get_all_library_releases import get_all_releases_of_library
from .tools.get_dependencies import get_library_dependency
from .tools.install_library import install_library
from .tools.is_user_have_library import is_user_have_library


import sys



def is_user_have_library (lib_name:str):
    """Check whether the user have the library in the current site-packages or not"""

    if lib_name in dict(sys.modules):
        return True
    else:
        return False


import requests, json

def get_library_dependency(lib_name:str):
    """Get the required packages by the library, returns a list of package names"""
    package_reqs = []
    get_dpdns = json.loads(requests.get(f"https://pypi.org/pypi/{lib_name}/json").text)['info']['requires_dist']

    for pkn in get_dpdns:
        full_name = ""
        complete_getten_litters = True
        for n in pkn:
            if n != "(" and n != ")" and n != ";" and complete_getten_litters:
                full_name = full_name + n
            else:
                complete_getten_litters = False
        package_reqs.append(full_name.replace(" ", ""))
    
    return package_reqs

if __name__ == "__main__":
    print(get_library_dependency("requests"))